package it.ovolollo.labs;

import javax.ejb.Local;
import javax.ejb.Stateless;
import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.DeliveryMode;
import javax.jms.JMSException;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;
import javax.jms.TextMessage;
import javax.jws.WebService;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;


/**
 * Session Bean implementation class SendMessage
 */
@WebService
@Stateless
@Local(SendMessageLocal.class)
public class SendMessage implements SendMessageLocal {
    
    @javax.annotation.Resource(name = "ConnectionFactory", mappedName = "jms/ConnectionFactory")
    private ConnectionFactory connectionFactory;
    
    @javax.annotation.Resource(mappedName = "wb25/queue/batch-response")
    private Queue batchResponseQueue;

    @PersistenceContext(unitName = "testXAqueue")
    private EntityManager entityManager;
    
    @Override
    public void runMe() {
        Connection conn = null;
        Session session = null;
        try {
            conn = connectionFactory.createConnection();
            session = conn.createSession(false, Session.AUTO_ACKNOWLEDGE);
            MessageProducer producer = session.createProducer(batchResponseQueue);
            producer.setDeliveryMode(DeliveryMode.PERSISTENT);
            
            TextMessage message = session.createTextMessage();
            
            TableTest tableTest = new TableTest();
            tableTest.setTesto("Ovolollo");
            entityManager.merge(tableTest);
            entityManager.flush();
            
            producer.send(message);
            System.out.println("Done");

        } catch (Exception e) {
            System.out.println("Error"+e.getMessage());
        } finally {
            if (conn == null) {
                return;
            }
            try {
                conn.close();
            } catch (Exception e) {
                System.out.println(e.getMessage());
            }
            if (session == null) {
                return;
            }
            try {
                session.close();
            } catch (Exception e) {
                System.out.println(e.getMessage());
            }
        }
        
    }

    
}
